## 0.0.32

This new version includes some internal code reorganization for better encapsulation and security.

### New Features

- No new features were added in this version.

### Code Improvements

- Moved 'codebot' and 'diffbot' into protected functions to enhance code security and maintainability (ce59a0c) (Eric Ma)

### Bug Fixes

- No bug fixes were included in this version.

### Deprecations

- No deprecations were made in this version.
